@@ -129,6 +129,7 @@ class vmmEngine(vmmGObject):
         self.systray.connect("action-shutdown-domain", self._do_shutdown_domain)
         self.systray.connect("action-reboot-domain", self._do_reboot_domain)
         self.systray.connect("action-destroy-domain", self._do_destroy_domain)
+        self.systray.connect("action-reset-domain", self._do_reset_domain)
         self.systray.connect("action-show-vm", self._do_show_vm)
         self.systray.connect("action-exit-app", self.exit_app)
 
@@ -159,7 +160,7 @@ class vmmEngine(vmmGObject):
             libvirt_packages = self.config.libvirt_packages
             packages = self.config.hv_packages + libvirt_packages
 
-            ret = packageutils.check_packagekit(self.err, packages, True)
+            ret = packageutils.check_packagekit(manager.err, packages, True)
         except:
             logging.exception("Error talking to PackageKit")
 
@@ -178,8 +179,11 @@ class vmmEngine(vmmGObject):
             manager.set_startup_error(msg)
             return
 
+        do_start = not did_install_libvirt
         if did_install_libvirt:
             didstart = packageutils.start_libvirtd()
+            do_start = didstart
+
             warnmsg = _(
                 "Libvirt was just installed, so the 'libvirtd' service will\n"
                 "will need to be started.\n"
@@ -187,10 +191,9 @@ class vmmEngine(vmmGObject):
                 "start up.")
 
             if not didstart:
-                self.err.ok(_("Libvirt service must be started"), warnmsg)
+                manager.err.ok(_("Libvirt service must be started"), warnmsg)
 
-        self.connect_to_uri(tryuri, autoconnect=True,
-                            do_start=not did_install_libvirt)
+        self.connect_to_uri(tryuri, autoconnect=True, do_start=do_start)
 
 
     def load_stored_uris(self):
@@ -573,6 +576,7 @@ class vmmEngine(vmmGObject):
         obj = vmmDetails(con.get_vm(uuid))
         obj.connect("action-save-domain", self._do_save_domain)
         obj.connect("action-destroy-domain", self._do_destroy_domain)
+        obj.connect("action-reset-domain", self._do_reset_domain)
         obj.connect("action-show-help", self._do_show_help)
         obj.connect("action-suspend-domain", self._do_suspend_domain)
         obj.connect("action-resume-domain", self._do_resume_domain)
@@ -622,6 +626,7 @@ class vmmEngine(vmmGObject):
         obj.connect("action-shutdown-domain", self._do_shutdown_domain)
         obj.connect("action-reboot-domain", self._do_reboot_domain)
         obj.connect("action-destroy-domain", self._do_destroy_domain)
+        obj.connect("action-reset-domain", self._do_reset_domain)
         obj.connect("action-save-domain", self._do_save_domain)
         obj.connect("action-migrate-domain", self._do_show_migrate)
         obj.connect("action-clone-domain", self._do_show_clone)
@@ -960,6 +965,22 @@ class vmmEngine(vmmGObject):
 
         vmmAsyncJob.simple_async_noshow(reboot_cb, [], src, "")
 
+    def _do_reset_domain(self, src, uri, uuid):
+        conn = self._lookup_conn(uri)
+        vm = conn.get_vm(uuid)
+
+        if not util.chkbox_helper(src, self.config.get_confirm_forcepoweroff,
+            self.config.set_confirm_forcepoweroff,
+            text1=_("Are you sure you want to force reset '%s'?" %
+                    vm.get_name()),
+            text2=_("This will immediately reset the VM without "
+                    "shutting down the OS and may cause data loss.")):
+            return
+
+        logging.debug("Resetting vm '%s'", vm.get_name())
+        vmmAsyncJob.simple_async_noshow(vm.reset, [], src,
+                                        _("Error resetting domain"))
+
 vmmGObject.type_register(vmmEngine)
 vmmEngine.signal_new(vmmEngine, "conn-added", [object])
 vmmEngine.signal_new(vmmEngine, "conn-removed", [str])
