@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2006 Red Hat, Inc.
+# Copyright (C) 2006, 2012 Red Hat, Inc.
 # Copyright (C) 2006 Daniel P. Berrange <berrange@redhat.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -49,6 +49,7 @@ class vmmPreferences(vmmGObjectUI):
         self.add_gconf_handle(self.config.on_confirm_removedev_changed(self.refresh_confirm_removedev))
         self.add_gconf_handle(self.config.on_confirm_interface_changed(self.refresh_confirm_interface))
         self.add_gconf_handle(self.config.on_confirm_unapplied_changed(self.refresh_confirm_unapplied))
+        self.add_gconf_handle(self.config.on_confirm_delstorage_changed(self.refresh_confirm_delstorage))
 
         self.refresh_view_system_tray()
         self.refresh_update_interval()
@@ -68,6 +69,7 @@ class vmmPreferences(vmmGObjectUI):
         self.refresh_confirm_removedev()
         self.refresh_confirm_interface()
         self.refresh_confirm_unapplied()
+        self.refresh_confirm_delstorage()
 
         self.window.connect_signals({
             "on_prefs_system_tray_toggled" : self.change_view_system_tray,
@@ -88,6 +90,7 @@ class vmmPreferences(vmmGObjectUI):
             "on_prefs_confirm_removedev_toggled": self.change_confirm_removedev,
             "on_prefs_confirm_interface_toggled": self.change_confirm_interface,
             "on_prefs_confirm_unapplied_toggled": self.change_confirm_unapplied,
+            "on_prefs_confirm_delstorage_toggled": self.change_confirm_delstorage,
             "on_prefs_btn_keys_define_clicked": self.change_grab_keys,
             "on_prefs_graphics_type_changed": self.change_graphics_type,
             "on_prefs_storage_format_changed": self.change_storage_format,
@@ -233,6 +236,10 @@ class vmmPreferences(vmmGObjectUI):
                                   ignore3=None, ignore4=None):
         self.widget("prefs-confirm-unapplied").set_active(
                                 self.config.get_confirm_unapplied())
+    def refresh_confirm_delstorage(self, ignore1=None, ignore2=None,
+                                   ignore3=None, ignore4=None):
+        self.widget("prefs-confirm-delstorage").set_active(
+                                self.config.get_confirm_delstorage())
 
     def grabkeys_get_string(self, events):
         keystr = ""
@@ -324,6 +331,8 @@ class vmmPreferences(vmmGObjectUI):
         self.config.set_confirm_interface(src.get_active())
     def change_confirm_unapplied(self, src):
         self.config.set_confirm_unapplied(src.get_active())
+    def change_confirm_delstorage(self, src):
+        self.config.set_confirm_delstorage(src.get_active())
 
     def change_graphics_type(self, src):
         gtype = 'vnc'
