@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 #
 # startpool.py - Copyright (C) 2009 Red Hat, Inc.
 # Written by Darryl L. Pierce <dpierce@redhat.com>
@@ -18,7 +17,7 @@
 # MA  02110-1301, USA.  A copy of the GNU General Public License is
 # also available at http://www.gnu.org/copyleft/gpl.html.
 
-import snack
+from snack import Label
 from storagelistconfigscreen import StorageListConfigScreen
 
 LIST_POOLS_PAGE    = 1
@@ -37,10 +36,6 @@ class StartStoragePoolConfigScreen(StorageListConfigScreen):
     def page_has_next(self, page):
         return page is LIST_POOLS_PAGE and self.has_selectable_pools()
 
-    def page_has_back(self, page):
-        ignore = page
-        return False
-
     def page_has_finish(self, page):
         return page is FINAL_PAGE
 
@@ -55,11 +50,11 @@ class StartStoragePoolConfigScreen(StorageListConfigScreen):
     def process_input(self, page):
         if page is LIST_POOLS_PAGE:
             self.get_libvirt().create_storage_pool(self.get_selected_pool())
-            self.set_finished()
 
     def get_final_page(self, screen):
         ignore = screen
-        return [snack.Label("Storage pool started: %s" % self.get_selected_pool())]
+        self.set_finished()
+        return [Label("Storage pool started: %s" % self.get_selected_pool())]
 
 def StartStoragePool():
     screen = StartStoragePoolConfigScreen()
